@@ -69,11 +69,7 @@ def pylint_scan(code_path, lint_rule='', disable=''):
         args.append(f'--disable={disable}')
     cmd = f"pylint {code_path} {' '.join(args)}"
     print(cmd)
-    subp = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE, stderr=subprocess.PIPE, text=True)
-    for i in iter(subp.stdout.readline, ''):
-        if len(i) < 1:
-            break
-        print(i.strip('\n'))
+    os.system(cmd)
     delete_init()
 
 
